import { Component, Input, ViewContainerRef, ComponentFactoryResolver, ViewChild, HostBinding, HostListener, ChangeDetectionStrategy } from '@angular/core';
import { trigger, transition, style, animate, state } from '@angular/animations';
import { Router, NavigationStart } from '@angular/router';
import { OverlayService } from 'a4-overlay';
import 'rxjs/add/operator/filter';
var ModalComponent = (function () {
    function ModalComponent(resolver, router, overlayService) {
        this.resolver = resolver;
        this.router = router;
        this.overlayService = overlayService;
        this.scaling = false;
    }
    ModalComponent.prototype.ngOnInit = function () {
        var _this = this;
        if (!!this.width) {
            this.hostWidth = this.width;
        }
        if (!!this.height) {
            this.hostHeight = this.height;
        }
        var factory = this.resolver.resolveComponentFactory(this.injectComponent.component);
        this.componentRef = this.viewContainerRef.createComponent(factory);
        if (!!this.injectComponent.inputs) {
            Object.keys(this.injectComponent.inputs)
                .forEach(function (key) { return _this.componentRef.instance[key] = _this.injectComponent.inputs[key]; });
        }
        this.componentRef.instance.modal = this;
        this.scaling = true;
        this.subscription = this.router.events
            .filter(function (p) { return p instanceof NavigationStart; })
            .subscribe(function () {
            _this.componentRef.destroy();
            _this.injectComponent.reject();
        });
        this.overlayService.show();
    };
    ModalComponent.prototype.ngOnDestroy = function () {
        this.overlayService.hide();
        this.subscription.unsubscribe();
    };
    ModalComponent.prototype.close = function (result) {
        this.result = result;
        this.scaling = false;
    };
    ModalComponent.prototype.animationDone = function (e) {
        if (!e.toState) {
            this.injectComponent.resolve(this.result);
            this.componentRef.destroy();
        }
    };
    return ModalComponent;
}());
export { ModalComponent };
ModalComponent.decorators = [
    { type: Component, args: [{
                selector: 'a4-modal',
                template: "<ng-template #container></ng-template>",
                styles: ["\n  :host {\n    display: block;\n    position: fixed;\n    z-index: 1000;\n    background-color: white;\n    left: 50vw;\n    top: 50vh;\n    border: 1px solid rgba(0,0,0,0.1);\n    border-radius: 4px;\n    box-shadow: 0 5px 5px -3px rgba(0,0,0,.2), 0 8px 10px 1px rgba(0,0,0,.14), 0 3px 14px 2px rgba(0,0,0,.12);\n  }\n  "],
                animations: [
                    trigger('scaling', [
                        state('0', style({ transform: 'translate(-50%, -50%) scale(0)' })),
                        state('1', style({ transform: 'translate(-50%, -50%) scale(1)' })),
                        transition(':enter', [style({ transform: 'translate(-50%, -50%) scale(0)' }), animate('250ms ease')]),
                        transition('1 => 0', animate('250ms ease'))
                    ])
                ],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
ModalComponent.ctorParameters = function () { return [
    { type: ComponentFactoryResolver, },
    { type: Router, },
    { type: OverlayService, },
]; };
ModalComponent.propDecorators = {
    'injectComponent': [{ type: Input },],
    'width': [{ type: Input },],
    'height': [{ type: Input },],
    'viewContainerRef': [{ type: ViewChild, args: ['container', { read: ViewContainerRef },] },],
    'scaling': [{ type: HostBinding, args: ['@scaling',] },],
    'hostWidth': [{ type: HostBinding, args: ['style.width',] },],
    'hostHeight': [{ type: HostBinding, args: ['style.height',] },],
    'animationDone': [{ type: HostListener, args: ['@scaling.done', ['$event'],] },],
};
//# sourceMappingURL=modal.component.js.map